Module buffer

Module buffer 

A module for the Buffer and Cell types.

Structs

Buffer
A buffer that maps to the desired content of the terminal after the draw call
BufferDiff
A zero-allocation iterator over the differences between two buffers of the same width.
Cell
A buffer cell

Enums

CellDiffOption
Cell diffing options

Traits

CellWidth
Returns the display width of a value in terminal cells.