pub enum CellDiffOption {
None,
Skip,
AlwaysUpdate,
ForcedWidth(NonZeroU16),
}Expand description
Cell diffing options
Variants
None
No special option.
Skip
Skip this cell when diffing.
This is helpful when it is necessary to prevent the buffer from overwriting a cell that is covered by something from an escape sequence, such as graphics or links.
AlwaysUpdate
Always update this cell when diffing.
This bypasses the equality check against the previous buffer. Use it when another renderer may draw over the same area, such as an external image pipeline, so Ratatui can redraw text there on the next render.
ForcedWidth(NonZeroU16)
Force a width regardless of the symbol text width.
Escape sequences will have some computed width that does match what is written to the screen.